#include "checkbox.h"

#include <uta/resources.h>

using namespace Janus;

CheckBox::CheckBox(const Parameters& param) :
  WidgetBase(param)
{
  assert(parent_);

  widget_ = new uta::Widget(parent_, 
			    rect_.upperLeft().x, rect_.upperLeft().y,
			    rect_.width(), rect_.height());
  assert(widget_);

  widget_->setAutoDelete(false);
  widget_->setColor(color_);
  if(Element::hasAttr("background"))
    widget_->setBackground(background_);

  button_ = new uta::ToggleButton(widget_,0,(rect_.height()-15)/2,15,15);
  button_->setColor(color_);

  button_->pressed.connect(SigC::slot(this, &CheckBox::slot_pressed));
  button_->released.connect(SigC::slot(this, &CheckBox::slot_released));
  
  label_ = new uta::Label(widget_,20,0,rect_.width()-20, rect_.height(), font_);
  label_->setColor(color_);

  std::string col = Element::getStringAttr("text_color","");
  std::string fade_col = Element::getStringAttr("fade_color",""); 
  if(RES_AVAILABLE(col) && RES_AVAILABLE(fade_col))
    label_->setTextColor(COLOR_RES(col), COLOR_RES(fade_col));
  else if(RES_AVAILABLE(col))
    label_->setTextColor(COLOR_RES(col));
  
  label_->setText(Element::getStringAttr("text").c_str());

}

void 
CheckBox::call(const std::string& name, const Value& val)
{
  if(name == "setEnabled")
    {
      if(val == "1")
	button_->press();
      else
	button_->release();
    }
  else if(name == "setDisabled")
    {
      if(val == "0")
	button_->press();
      else
	button_->release();
    }
  else
    {
      WidgetBase::call(name, val);
    }
}

Value
CheckBox::getValue(void) const
{
  if(button_->isPressed())
    return "1";
  return "0";
}

void
CheckBox::slot_released()
{
  ElementSigC::emit("released");
  ElementSigC::emit("toggled","0");
}
  

void
CheckBox::slot_pressed()
{
  ElementSigC::emit("pressed");
  ElementSigC::emit("toggled","1");
}
  
