#include "lineedit.h"
#include <uta/lineedit.h>
#include <uta/resources.h>

using namespace Janus;

LineEdit::LineEdit(const Parameters& param) :
  WidgetBase(param)
{
  assert(parent_);
  
  uta::LineEdit* lineedit
    = new uta::LineEdit(parent_, rect_.upperLeft().x, rect_.upperLeft().y,
		     rect_.width(), rect_.height(), font_);
  assert(lineedit); 
  lineedit->textChanged.connect(SigC::slot(this, &LineEdit::slot_textChanged));
  lineedit->enterPressed.connect(SigC::slot(this, &LineEdit::slot_enterPressed));
   
  lineedit->setText(Element::getStringAttr("text").c_str());  

  std::string col = Element::getStringAttr("text_color","");
  std::string fade_col = Element::getStringAttr("fade_color",""); 
  if(RES_AVAILABLE(col) && RES_AVAILABLE(fade_col))
    lineedit->setTextColor(COLOR_RES(col), COLOR_RES(fade_col));
  else if(RES_AVAILABLE(col))
    lineedit->setTextColor(COLOR_RES(col));


  widget_ = lineedit;
  widget_->setAutoDelete(false);
  widget_->setColor(color_);

  if(hasAttr("background"))
    widget_->setBackground(background_);
}

void 
LineEdit::call(const std::string& name, const Value& val)
{
  // dynamic_cast<uta::Lineedit*> returns non-valid pointers !!!
  uta::LineEdit* lineedit = (uta::LineEdit*)widget_;
  
  if(name == "setText")
    {
      lineedit->setText(val.c_str());
    }
  else
    {
      WidgetBase::call(name, val);
    }
}

void
LineEdit::setValue(const Value& val)
{
  uta::LineEdit* lineedit = (uta::LineEdit*)widget_;
  lineedit->setText(val.c_str());
}

Value 
LineEdit::getValue(void) const
{
  uta::LineEdit* lineedit = (uta::LineEdit*)widget_;
  return lineedit->getText();
}

void
LineEdit::slot_enterPressed(const char* txt)
{
  ElementSigC::emit("returnPressed", std::string(txt));
}

void
LineEdit::slot_textChanged(const char* txt)
{
  ElementSigC::emit("textChanged", std::string(txt)); 
}
