#include "pushbutton.h"
#include <uta/pushbutton.h>
#include <uta/resources.h>

using namespace Janus;

PushButton::PushButton(const Parameters& param) :
  WidgetBase(param)
{
  assert(parent_);

  uta::PushButton* button
    = new uta::PushButton(parent_, rect_.upperLeft().x, rect_.upperLeft().y,
			  rect_.width(), rect_.height(), 
	                  Element::getIntAttr("button"));
  assert(button); 

  std::string col = Element::getStringAttr("text_color","");
  std::string fade_col = Element::getStringAttr("fade_color",""); 
  if(RES_AVAILABLE(col) && RES_AVAILABLE(fade_col))
    button->setTextColor(COLOR_RES(col), COLOR_RES(fade_col));
  else if(RES_AVAILABLE(col))
    button->setTextColor(COLOR_RES(col));

  widget_ = button;

  widget_->setAutoDelete(false);

  widget_->setColor(color_);
  if(hasAttr("background"))
    widget_->setBackground(background_);

  button->clicked1.connect(SigC::slot(this, &PushButton::slot_clicked));

  button->setText(Element::getStringAttr("text").c_str());


  if(Element::hasAttr("image_up"))
    button->setUpPic(SURFACE_RES(Element::getStringAttr("image_up","")));
  if(Element::hasAttr("image_down"))
    button->setUpPic(SURFACE_RES(Element::getStringAttr("image_down","")));

}

void 
PushButton::call(const std::string& name, const Value& val)
{
  WidgetBase::call(name, val);

  // dynamic_cast<uta::PushButton*> returns non-valid pointers !!!
  //  uta::PushButton* button = (uta::PushButton*)widget_;
  if(name == "setText")
    {
      ((uta::PushButton*)widget_)->setText(val.c_str());
    }
  else
    {
      WidgetBase::call(name, val);
    }
}

void
PushButton::slot_clicked(int button)
{
  char buffer[32];
  sprintf(buffer,"%d",button);
  ElementSigC::emit("clicked", buffer);
}
  

