#include "slider.h"
#include <uta/slider.h>
#include <uta/resources.h>

using namespace Janus;

Slider::Slider(const Parameters& param) :
  WidgetBase(param)
{
  assert(parent_);

  int orientation;
  if(Element::getStringAttr("orientation") == "Horizontal")
    orientation = uta::Slider::HORIZONTAL;
  else
    orientation = uta::Slider::VERTICAL;

  uta::Slider* slider
    = new uta::Slider(parent_, rect_.upperLeft().x, rect_.upperLeft().y,
		     rect_.width(), rect_.height(), orientation);
  assert(slider); 

  slider->valueChanged.connect(SigC::slot(this, &Slider::slot_sliderMoved));
  
  std::string col = Element::getStringAttr("button_color","");
  if(RES_AVAILABLE(col))
    slider->setButtonColor(COLOR_RES(col));

  slider->setValue(Element::getIntAttr("value",50));
  slider->setRange(Element::getIntAttr("minValue",0),
		   Element::getIntAttr("maxValue",100));

  widget_ = slider;
  widget_->setAutoDelete(false);
  widget_->setColor(color_);
  if(Element::hasAttr("background"))
    widget_->setBackground(background_);
 
}

void 
Slider::call(const std::string& name, const Value& val)
{
  // dynamic_cast<uta::Slider*> returns non-valid pointers !!!
  uta::Slider* slider = (uta::Slider*)widget_;
  
  if(name == "setValue")
    {
      slider->setValue(atoi(val.c_str()));
    }
  else
    {
      WidgetBase::call(name, val);
    }
}

void 
Slider::setValue(const Value& val)
{
  uta::Slider* slider = (uta::Slider*)widget_;
  slider->setValue(atoi(val.c_str()));
}

Value 
Slider::getValue(void) const
{
  uta::Slider* slider = (uta::Slider*)widget_;
  int value = slider->value();
  
  char buffer[32];
  sprintf(buffer,"%d",value);

  return std::string(buffer);
}

void
Slider::slot_sliderMoved(int val)
{
  char buffer[32];
  sprintf(buffer,"%d",val);
  ElementSigC::emit("sliderMoved", std::string(buffer));
}


