//  The Worldforge Project
//  Copyright (C) 1998, 1999 The Worldforge Project
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//  For information about Worldforge and its authors, please contact
//  the Worldforge Web Site at http://www.worldforge.org.
//
// created by Karsten Laux 11/2000


#ifndef _JANUS_CONNECTION_H_
#define _JANUS_CONNECTION_H_

#include "element.h"
#include "factory.h"

namespace Janus {

/** Dynamic Connection.
    This is a QT-like connection class. It connects the named event of one Element 
    with the named method of another Element. It may also connect event and method of
    the same Element.
    The Connection is established as long as the Connection object lives; if deleted the 
    connection should get deleted as well.
*/
class Connection 
{
 public:

  ///
  typedef struct 
  {
    Element* creator;
    std::string signal;
    Element* consumer;
    std::string slot;
  } Parameters;

  /** register new factory.
      ConnectionFactory takes over ownership for the factory !
  */
  static void registerFactory(const std::string&, Janus::Factory<Connection>*);
  ///
  static Connection* createConnection(const Connection::Parameters&);
  ///
  static void cleanup();

  ///
  template <typename T> class Factory : public Janus::Factory<Connection>
    {
    public:
      Factory(const std::string& type): Janus::Factory<Connection>()
        {
	  Connection::registerFactory(type, this);
        }
 
        virtual Connection* New(const Parameters& p)
        {
	  return  new T(p);
        }
 
        virtual void Delete(Connection* element)
        {
	  delete element;
        }
    };
  ///
  virtual ~Connection();

 protected:
  ///
  Connection(const Parameters&) {};
  ///
  static Janus::Factory<Connection>* factory_;

};

}

#endif
